farepa package
==============

Submodules
----------

farepa.cli module
-----------------

.. automodule:: farepa.cli
    :members:
    :undoc-members:
    :show-inheritance:

farepa.farepa module
--------------------

.. automodule:: farepa.farepa
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: farepa
    :members:
    :undoc-members:
    :show-inheritance:
